/*
 Esplora_lettura_batteria
 Il programma legge la tensione della batteria LI-PO
 di alimentazione letta tramite la porta IN-A 
 
 Creato il 12/9/2012
 da Adriano Gandolfo <http://www.adrirobot.it>
 This example code is in the public domain.
 */

// Include le librerie necessarie
#include <Esplora.h>  
#include <TFT.h>       // Libreria per LCD ArduinoLCD library
#include <SPI.h>

//Definizione variabile di servizio
int BatteryValue = 0;
char tensione1 [50];
String BatteryValue1;
char batteryPrintout[5];
char valuePrintout[5];
float fBattVoltage = 0;
int iBattVoltage = 0;

//Programma derivato dal sito di Mike Barela per la lettura delle porte analogiche 
// http://21stdigitalhome.blogspot.it/2013/03/reading-arduino-esplora-tinkerkit-inputs.html

const byte CH_TINKERKIT_INA = 8;   // Add values missing from Esplora.h
const byte CH_TINKERKIT_INB = 9;
const byte INPUT_A          = 0;
const byte INPUT_B          = 1;

unsigned int readTinkerkitInput(byte whichInput) {  // return 0-1023 from Tinkerkit Input A or B
  return readChannel(whichInput+CH_TINKERKIT_INA); 
}   //   as defined above

unsigned int readChannel(byte channel) {        // as Esplora.readChannel is a private function
  digitalWrite(A0, (channel & 1) ? HIGH : LOW); //  we declare our own as a hack
  digitalWrite(A1, (channel & 2) ? HIGH : LOW); //
  digitalWrite(A2, (channel & 4) ? HIGH : LOW); // digitalWrite sets address lines for the input
  digitalWrite(A3, (channel & 8) ? HIGH : LOW);
  return analogRead(A4);                        // analogRead gets value from MUX chip
}

void setup() {
  Serial.begin(9600);
  // Inizializzazione del display grafico
  EsploraTFT.begin();

  // cancella lo schermo con uno sfondo nero
  EsploraTFT.background(0,0,0);

  // Imposta il colore del testo a viola
  EsploraTFT.stroke(255,0,255);
  // Imposta altezza testo a 2
  EsploraTFT.setTextSize(2);
  // Avviare il testo nella parte superiore sinistra dello schermo
  // Questo testo rimarra' statico
  EsploraTFT.text("Tensione: \n ",0,0);

  // Imposta altezza testo per il loop a 5
  EsploraTFT.setTextSize(5);
}

void loop() {

  // lettura valore della tensione e inserimeto valore in
  // una variabile
  unsigned int BatteryValue= readTinkerkitInput(INPUT_A);

  // Calcolo del valore della tensione della batteria
  float fBattVoltage = ((BatteryValue*5.0)/1023)*1000.0;

  iBattVoltage = (int)fBattVoltage; // Conversione del valore float in integer
  char battVoltageStr[50]; //Asseganzione a char
  sprintf(battVoltageStr,"%d",iBattVoltage); // Copia intero char come stringa
  // Utilizzando gli argomenti indicizzati viene messo ogni numero al posto giusto
  // nota il punto decimale e' inserito manualmente.
  sprintf(tensione1,"%c.%c%cV",battVoltageStr[0],battVoltageStr[1],battVoltageStr[2]);

  // Conversione valore letto da porta analogica in stringa
  BatteryValue1= String (BatteryValue);
  BatteryValue1.toCharArray (valuePrintout, 6);

  // imposta il colore del testo a rosso
  EsploraTFT.stroke(255,0,0);
  // stampa su LCD valore letto e di quello in volt
  EsploraTFT.text(tensione1, 0, 80);
  // imposta il colore del testo a verde
  EsploraTFT.stroke(0,255,0);
  // stampa su LCD valore letto dall' ADC
  EsploraTFT.text(valuePrintout, 0, 30); 

  //Puasa di un secondo per la prossima lettura
  delay(1000); 

  // cancella il testo per la prossima lettura
  EsploraTFT.stroke(0,0,0);
  EsploraTFT.text(tensione1, 0, 80);
  EsploraTFT.text(valuePrintout, 0, 30);
}

